%global commit 7cdbf1ed4b94259a3aad2a7575e928fa61b0e57e
%global shortcommit %(c=%{commit}; echo ${c:0:9})

Name:		lld
Version:	11.0.0
Release: 0.25.git%{shortcommit}%{?dist}
Summary:	The LLVM Linker

License:	NCSA
URL:		http://llvm.org
Source0:        %{name}-%{shortcommit}.tar.xz
Source1:	run-lit-tests
Source2:	lit.lld-test.cfg.py

Patch0:		0001-CMake-Check-for-gtest-headers-even-if-lit.py-is-not-.patch

BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	cmake
BuildRequires:	llvm-devel = %{version}
BuildRequires:	llvm-test = %{version}
BuildRequires:	ncurses-devel
BuildRequires:	zlib-devel
BuildRequires:	chrpath

# For make check:
BuildRequires:	python3-rpm-macros
BuildRequires:	python3-lit
BuildRequires:	llvm-googletest = %{version}

# For gpg source verification
BuildRequires:	gnupg2

Requires(post): %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives

Requires: lld-libs = %{version}-%{release}

%description
The LLVM project linker.

%package devel
Summary:	Libraries and header files for LLD
Requires: lld-libs = %{version}-%{release}

%description devel
This package contains library and header files needed to develop new native
programs that use the LLD infrastructure.

%package libs
Summary:	LLD shared libraries

%description libs
Shared libraries for LLD.

%package test
Summary: LLD regression tests
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	python3-lit
Requires:	llvm-test(major) = %{maj_ver}
Requires:	lld-libs = %{version}-%{release}

%description test
LLVM regression tests.

%prep
%autosetup -n %{name}-%{shortcommit}

%build

mkdir %{_target_platform}
cd %{_target_platform}

%cmake .. \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_DYLIB_COMPONENTS="all" \
	-DPYTHON_EXECUTABLE=%{__python3} \
	-DLLVM_INCLUDE_TESTS=ON \
	-DLLVM_MAIN_SRC_DIR=%{_datadir}/llvm/src \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DLLVM_LIT_ARGS="-sv \
	--path %{_libdir}/llvm" \
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64
%else
	-DLLVM_LIBDIR_SUFFIX=
%endif

%make_build

# Build the unittests so we can install them.
%make_build lld-test-depends

%install

%global lit_cfg test/%{_arch}.site.cfg.py
%global lit_unit_cfg test/Unit/%{_arch}.site.cfg.py
%global lit_lld_test_cfg_install_path %{_datadir}/lld/lit.lld-test.cfg.py

# Generate lit config files.  Strip off the last line that initiates the
# test run, so we can customize the configuration.
head -n -1 %{_target_platform}/test/lit.site.cfg.py >> %{lit_cfg}
head -n -1 %{_target_platform}/test/Unit/lit.site.cfg.py >> %{lit_unit_cfg}

# Patch lit config files to load custom config:
for f in %{lit_cfg} %{lit_unit_cfg}; do
  echo "lit_config.load_config(config, '%{lit_lld_test_cfg_install_path}')" >> $f
done

# Install test files
install -d %{buildroot}%{_datadir}/lld/src
cp %{SOURCE2} %{buildroot}%{_datadir}/lld/

tar -czf %{buildroot}%{_datadir}/lld/src/test.tar.gz test/
install -d %{buildroot}%{_libexecdir}/tests/lld
cp %{SOURCE1} %{buildroot}%{_libexecdir}/tests/lld

# Install unit test binaries
install -d %{buildroot}%{_libdir}/lld/
cp -R %{_target_platform}/unittests %{buildroot}%{_libdir}/lld/
rm -rf `find %{buildroot}%{_libdir}/lld/ -iname '*make*'`

# Install gtest libraries
cp %{_target_platform}/%{_lib}/libgtest*so* %{buildroot}%{_libdir}/lld/

# Install libraries and binaries
cd %{_target_platform}
%make_install

# Remove rpath
chrpath --delete %{buildroot}%{_bindir}/*
chrpath --delete %{buildroot}%{_libdir}/*.so*
chrpath --delete `find %{buildroot}%{_libdir}/lld/ -type f`

# Required when using update-alternatives:
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Alternatives/
touch %{buildroot}%{_bindir}/ld

%post
%{_sbindir}/update-alternatives --install %{_bindir}/ld ld %{_bindir}/ld.lld 1

%postun
if [ $1 -eq 0 ] ; then
  %{_sbindir}/update-alternatives --remove ld %{_bindir}/ld.lld
fi

%check

# armv7lhl tests disabled because of arm issue, see https://koji.fedoraproject.org/koji/taskinfo?taskID=33660162
%ifnarch %{arm}
make -C %{_target_platform} %{?_smp_mflags} check-lld
%endif

%ldconfig_scriptlets libs

%files
%ghost %{_bindir}/ld
%{_bindir}/lld*
%{_bindir}/ld.lld
%{_bindir}/ld64.lld
%{_bindir}/wasm-ld

%files devel
%{_includedir}/lld
%{_libdir}/liblld*.so

%files libs
%{_libdir}/liblld*.so.*

%files test
%{_libexecdir}/tests/lld/
%{_libdir}/lld/
%{_datadir}/lld/src/test.tar.gz
%{_datadir}/lld/lit.lld-test.cfg.py

%changelog

